from __future__ import absolute_import, division, print_function

from ispyb.interface.dataarea import DataArea

class IF(DataArea):
    pass
